@@ -270,15 +270,15 @@ class UniProt:
         'ft_act_site',
         'cc_activity_regulation',
         'ft_binding',
-        'ft_ca_bind',
+        #'ft_ca_bind',
         'cc_catalytic_activity',
         'cc_cofactor',
         'ft_dna_bind',
         'ec',
         'cc_function',
         'kinetics',
-        'ft_metal',
-        'ft_np_bind',
+        #'ft_metal',
+        #'ft_np_bind',
         'cc_pathway',
         'ph_dependence',
         'redox_potential',
@@ -771,6 +771,15 @@ class UniProt:
             set it to None to keep all entries but this will be very slow
         :return: dataframe with indices being the uniprot id (e.g. DIG1_YEAST)
 
+        To get about 100 columns related to the accession P62988, type:
+
+            df = u.get_df('P62988')
+
+        Note that you may preceed the accesion by the keyword **sec_acc) to access secondary 
+        accessions numbers::
+
+            df = u.get_df('sec_acc:P62988')
+
         """
         if isinstance(entries, str):
             entries = [entries]
@@ -812,30 +821,12 @@ class UniProt:
                 if isinstance(output, type(None)):
                     output = df.copy()
                 else:
-                    output = output.append(df, ignore_index=True)
+                    # output = output.append(df, ignore_index=True)
+                    output = pd.concat([output, df], ignore_index=True)
 
         # you may end up with duplicated...
         output.drop_duplicates(inplace=True)
-        columns = [
-            "lit_pubmed_id",
-            "protein_families",
-            "Gene names",
-            "go",
-            "go_ids",
-            "interaction",
-            "keyword",
-        ]
-        for col in columns:
-            try:
-                res = output[col].apply(
-                    lambda x: [
-                        this.strip() for this in str(x).split(";") if this != "nan"
-                    ]
-                )
-                output[col] = res
-            except:
-                self.services.logging.warning("column could not be parsed. %s" % col)
-        # Sequences are splitted into chunks of 10 characters. let us rmeove
+        # Sequences are splitted into chunks of 10 characters. let us remove
         # the spaces:
         if "sequence" in output.columns:
             output["sequence"].fillna("", inplace=True)
